pub struct ConfigurationGetConfigurationResponse {
pub device_desc: DeviceDescriptor,
pub config_descriptors: Vec<Vec<FunctionDescriptor>>,
}Fields
device_desc: DeviceDescriptorconfig_descriptors: Vec<Vec<FunctionDescriptor>>Trait Implementations
Sourceimpl Clone for ConfigurationGetConfigurationResponse
impl Clone for ConfigurationGetConfigurationResponse
Sourcefn clone(&self) -> ConfigurationGetConfigurationResponse
fn clone(&self) -> ConfigurationGetConfigurationResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<ConfigurationGetConfigurationResponse, D> for ConfigurationGetConfigurationResponse
impl<D: ResourceDialect> Decode<ConfigurationGetConfigurationResponse, D> for ConfigurationGetConfigurationResponse
Sourceimpl<D: ResourceDialect> Encode<ConfigurationGetConfigurationResponse, D> for &ConfigurationGetConfigurationResponse
impl<D: ResourceDialect> Encode<ConfigurationGetConfigurationResponse, D> for &ConfigurationGetConfigurationResponse
Sourceimpl<D: ResourceDialect, T0: Encode<DeviceDescriptor, D>, T1: Encode<Vector<Vector<FunctionDescriptor, 32>, 5>, D>> Encode<ConfigurationGetConfigurationResponse, D> for (T0, T1)
impl<D: ResourceDialect, T0: Encode<DeviceDescriptor, D>, T1: Encode<Vector<Vector<FunctionDescriptor, 32>, 5>, D>> Encode<ConfigurationGetConfigurationResponse, D> for (T0, T1)
impl Persistable for ConfigurationGetConfigurationResponse
impl StructuralPartialEq for ConfigurationGetConfigurationResponse
Sourceimpl TypeMarker for ConfigurationGetConfigurationResponse
impl TypeMarker for ConfigurationGetConfigurationResponse
Sourcetype Owned = ConfigurationGetConfigurationResponse
type Owned = ConfigurationGetConfigurationResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ConfigurationGetConfigurationResponse
impl ValueTypeMarker for ConfigurationGetConfigurationResponse
Sourcetype Borrowed<'a> = &'a ConfigurationGetConfigurationResponse
type Borrowed<'a> = &'a ConfigurationGetConfigurationResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for ConfigurationGetConfigurationResponse
impl RefUnwindSafe for ConfigurationGetConfigurationResponse
impl Send for ConfigurationGetConfigurationResponse
impl Sync for ConfigurationGetConfigurationResponse
impl Unpin for ConfigurationGetConfigurationResponse
impl UnsafeUnpin for ConfigurationGetConfigurationResponse
impl UnwindSafe for ConfigurationGetConfigurationResponse